# Table of Contents

- [workspace-settings-overview](<./workspace-settings-overview.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Workspace Settings Overview](<./Workspace-Settings-Overview.md>)
  - [Basic Settings](<./Workspace-Settings-Overview/Basic-Settings.md>)
  - [Advanced Settings](<./Workspace-Settings-Overview/Advanced-Settings.md>)
  - [Discovery and Integrations](<./Workspace-Settings-Overview/Discovery-and-Integrations.md>)
